@@ -2,10 +2,9 @@ package Math::BigInt::CalcEmu;
 
 use 5.006002;
 use strict;
-# use warnings;	# do not use warnings for older Perls
-use vars qw/$VERSION/;
+use warnings;
 
-$VERSION = '1.999706';
+our $VERSION = '1.999707';
 
 package Math::BigInt;
 
